@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw/autobox/;
 
-our $VERSION = "1.010";
+our $VERSION = "1.011";
 
 =head1 NAME
 
@@ -659,7 +659,55 @@ sub key_value_if_defined {
     );
 }
 
-sub grep {
+
+
+sub map_each {
+    my $hash = shift;
+    my ($key_value_subref) = @_;
+    $key_value_subref //= "";
+    ref($key_value_subref) eq "CODE"
+        or Carp::croak("map_each(\$key_value_subref): \$key_value_subref ($key_value_subref) is not a sub ref");
+    my $new_hash = {
+        map { ## no critic
+            my $key = $_;
+            my $value = $hash->{$key};
+            {
+                local $_ = $value;
+                my (@new_key_value) = $key_value_subref->($key, $value);
+                @new_key_value >= 3 and Carp::croak("map_each \$key_value_subref returned more than the new key and value");
+                ( @new_key_value[ 0..1 ]);
+            }
+        }
+        keys %$hash,
+    };
+
+    return wantarray ? %$new_hash : $new_hash;
+}
+
+sub map_each_to_array {
+    my $hash = shift;
+    my ($array_item_subref) = @_;
+    $array_item_subref //= "";
+    ref($array_item_subref) eq "CODE"
+        or Carp::croak("map_each_to_array(\$array_item_subref): \$array_item_subref ($array_item_subref) is not a sub ref");
+    my $new_array = [
+        map { ## no critic
+            my $key = $_;
+            my $value = $hash->{$key};
+            {
+                local $_ = $value;
+                $array_item_subref->($key, $value);
+            }
+        }
+        sort keys %$hash,
+    ];
+
+    return wantarray ? @$new_array : $new_array;
+}
+
+
+
+sub grep_each {
     my $hash = shift;
     my ($subref) = @_;
     $subref ||= sub { !! $_ }; # true?
@@ -680,12 +728,16 @@ sub grep {
 
     return wantarray ? %$new_hash : $new_hash;
 }
+*grep = \&grep_each;
 
-sub grep_defined {
+sub grep_each_defined {
     my $hash = shift;
     return &grep($hash, sub { defined($_) });
 }
-
+{
+    no warnings "once";
+    *grep_defined = \&grep_each_defined;
+}
 
 
 
